from django.db import models
from account.models import Account  # Assuming Account is the user model
from django.utils.timezone import now


class Attendance(models.Model):
    user = models.ForeignKey(Account, on_delete=models.CASCADE)
    check_in_time = models.DateTimeField(null=True, blank=True)
    check_out_time = models.DateTimeField(null=True, blank=True)
    check_in_location = models.CharField(max_length=255, null=True, blank=True)  # Store location during check-in
    check_out_location = models.CharField(max_length=255, null=True, blank=True)  # Store location during check-out
    date = models.DateField(default=now)  # Defaults to the current date
    hours_worked = models.DurationField(null=True, blank=True)  # Stores hours worked

    def save(self, *args, **kwargs): 
        if self.check_in_time and self.check_out_time:
            self.hours_worked = self.check_out_time - self.check_in_time
        else:
            self.hours_worked = None
        super().save(*args, **kwargs)

    def __str__(self):
        return f"{self.user.email} - {self.date}"
 
